| Title: | Repbox for R code files in code supplements |
|---|---|
| Description: | Repbox for R code files in code supplements |
| Authors: | Sebastian Kranz |
| Maintainer: | Sebastian Kranz <[email protected]> |
| License: | GPL >= 3.0 |
| Version: | 0.1.0 |
| Built: | 2026-07-04 07:53:42 UTC |
| Source: | https://github.com/repboxr/repboxR |